﻿// (C) Copyright 2012 by Microsoft 
//
using System;
using Autodesk.AutoCAD.Runtime;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.Geometry;
using Autodesk.AutoCAD.EditorInput;

// This line is not mandatory, but improves loading performances
[assembly: CommandClass(typeof(Lab2.MyCommands))]

namespace Lab2
{

    // This class is instantiated by AutoCAD for each document when
    // a command is called by the user the first time in the context
    // of a given document. In other words, non static data in this class
    // is implicitly per-document!
    public class MyCommands
    {
        // The CommandMethod attribute can be applied to any public  member 
        // function of any public class.
        // The function should take no arguments and return nothing.
        // If the method is an intance member then the enclosing class is 
        // intantiated for each document. If the member is a static member then
        // the enclosing class is NOT intantiated.
        //
        // NOTE: CommandMethod has overloads where you can provide helpid and
        // context menu.

        // Modal Command with localized name
        [CommandMethod("MyGroup", "MyCommand", "MyCommandLocal", CommandFlags.Modal)]
        public void MyCommand() // This method can have any name
        {
            // Put your command code here

        }

        // Modal Command with pickfirst selection
        [CommandMethod("MyGroup", "MyPickFirst", "MyPickFirstLocal", CommandFlags.Modal | CommandFlags.UsePickSet)]
        public void MyPickFirst() // This method can have any name
        {
            PromptSelectionResult result = Application.DocumentManager.MdiActiveDocument.Editor.GetSelection();
            if (result.Status == PromptStatus.OK)
            {
                // There are selected entities
                // Put your command using pickfirst set code here
            }
            else
            {
                // There are no selected entities
                // Put your command code here
            }
        }

        // Application Session Command with localized name
        [CommandMethod("MyGroup", "MySessionCmd", "MySessionCmdLocal", CommandFlags.Modal | CommandFlags.Session)]
        public void MySessionCmd() // This method can have any name
        {
            // Put your command code here
        }

        // LispFunction is similar to CommandMethod but it creates a lisp 
        // callable function. Many return types are supported not just string
        // or integer.
        [LispFunction("MyLispFunction", "MyLispFunctionLocal")]
        public int MyLispFunction(ResultBuffer args) // This method can have any name
        {
            // Put your command code here

            // Return a value to the AutoCAD Lisp Interpreter
            return 1;
        }

        [CommandMethod("AddEnt")]
        public void AddEnt()
        {
            //get editor 
            Editor ed = Application.DocumentManager.MdiActiveDocument.Editor;

            PromptKeywordOptions getWhichEntityOpts = new PromptKeywordOptions("which type do you want ? [Circle/Block]", "Circle Block");

            PromptResult getWhichEntityResult = ed.GetKeywords(getWhichEntityOpts);
            if (getWhichEntityResult.Status == PromptStatus.OK)
            {
                switch (getWhichEntityResult.StringResult)
                {
                    case "Circle":
                        PromptPointOptions getCenterOpts = new PromptPointOptions("\n select center: ");
                        PromptPointResult getCenterResult = ed.GetPoint(getCenterOpts);
                        if (getCenterResult.Status == PromptStatus.OK)
                        {
                            Point3d center = getCenterResult.Value;

                            double radius = 0;

                            PromptDistanceOptions getRadiusOpts = new PromptDistanceOptions("\n input radius: ");
                            getRadiusOpts.BasePoint = center;
                            getRadiusOpts.UseBasePoint = true;

                            PromptDoubleResult getRadiusResult = ed.GetDistance(getRadiusOpts);
                            if (getRadiusResult.Status == PromptStatus.OK)
                            {
                                radius = getRadiusResult.Value;


                                ed.WriteMessage("\n Center is : " + center.ToString() + " radius is : " + radius.ToString());
                            }

                        }

                        break;

                    case "Block":
                        PromptStringOptions getBlockNameOpts = new PromptStringOptions("\n input block name: ");
                        getBlockNameOpts.AllowSpaces = false;

                        PromptResult getBlockNameResult = ed.GetString(getBlockNameOpts);
                        if (getBlockNameResult.Status == PromptStatus.OK)
                        {
                            string blockName = getBlockNameResult.StringResult;

                            ed.WriteMessage("\n the block name is : " + blockName);
                            
                        }

                        break;
                    default:
                        break;
                }
                
            }


        }

    }

}
